==> nextcloud-14.0.1.tgz: nextcloud/apps/files/l10n/sk.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
    "Storage invalid" : "Úložisko nie je platné",
    "Unknown error" : "Neznáma chyba",
    "All files" : "Všetky súbory",
    "Recent" : "Nedávne",
    "Favorites" : "Obľúbené",
    "File could not be found" : "Súbor nie je možné nájsť",
    "Move or copy" : "Presunúť alebo kopírovať",
    "Download" : "Sťahovanie",
    "Delete" : "Zmazať",
    "Home" : "Domov",
    "Close" : "Zavrieť",
    "Could not create folder \"{dir}\"" : "Nemožno vytvoriť priečinok \"{dir}\"",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cieľový priečinok \"{dir}\" už neexistuje",
    "Not enough free space" : "Nedostatok voľného miesta",
    "Uploading …" : "Nahrávanie...",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Cieľový priečinok už neexistuje",
    "Error when assembling chunks, status code {status}" : "Chyba pri zostavovaní kusov, kód chyby {status}",
    "Actions" : "Akcie",
    "Rename" : "Premenovať",
    "Copy" : "Kopírovať",
    "Target folder" : "Cieľový priečinok",
    "Disconnect storage" : "Odpojiť úložisko",
    "Unshare" : "Zneprístupniť",
    "Could not load info for file \"{file}\"" : "Nebolo možné načítať informácie súboru \"{file}\"",
    "Files" : "Súbory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrať",
    "Pending" : "Čaká",
    "Unable to determine date" : "Nemožno určiť dátum",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť \"{file}\", cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Nie je možné presunúť \"{file}\", cieľ už existuje",
    "Could not copy \"{file}\"" : "Nie je možné skopírovať \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopírované {origin} do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopírované {origin} a {nbfiles} ostatných súborov do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie je možné premenovať \"{fileName}\", cieľ už neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{targetName}\" je už použitý v priečinku \"{dir}\". Zvoľte prosím iný názov.",
    "Could not rename \"{fileName}\"" : "Nie je možné premenovať \"{file}\"",
    "Could not create file \"{file}\"" : "Nie je možné vytvoriť súbor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie je možné vytvoriť súbor \"{file}\" lebo už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Nie je možné vytvoriť priečinok \"{dir}\" lebo už existuje",
    "Error deleting file \"{fileName}\"." : "Chyba pri mazaní súboru \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žiadne výsledky vyhľadávania v ostatných priečinkoch pre {tag}{filter}{endtag}",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov","%n priečinkov"],
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov","%n súborov"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["vrátane %n skytého","vrátane %n skrytých","vrátane %n skrytých","vrátane %n skrytých"],
    "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávam %n súbor","Nahrávam %n súbory","Nahrávam %n súborov","Nahrávam %n súborov"],
    "New" : "Nový",
    "{used} of {quota} used" : "použitých {used} z {quota}",
    "{used} used" : "{used} použitých",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" nie je povolený v názve súboru.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie je povolený typ súboru",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'"],
    "View in folder" : "Zobraziť v priečinku",
    "Copied!" : "Skopírované!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre používateľov, ktorí majú prístup k tomuto súboru/priečinku)",
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
    "Favorited" : "Pridané k obľúbeným",
    "Favorite" : "Obľúbené",
    "New folder" : "Nový priečinok",
    "Upload file" : "Nahrať súbor",
    "Not favorited" : "Nie je obľúbený",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add to favorites" : "Pridať do obľúbených",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "Added to favorites" : "Pridané do obľúbených",
    "Removed from favorites" : "Odstránené z obľúbených",
    "You added {file} to your favorites" : "Pridali ste {file} do vašich obľúbených",
    "You removed {file} from your favorites" : "Odstránili ste {file} z vašich obľúbených",
    "File changes" : "Zmeny v súboroch",
    "Created by {user}" : "Vytvorené užívateľom {user}",
    "Changed by {user}" : "Zmenené užívateľom {user}",
    "Deleted by {user}" : "Zmazané užívateľom {user}",
    "Restored by {user}" : "Obnovené užívateľom {user}",
    "Renamed by {user}" : "Premenované užívateľom {user}",
    "Moved by {user}" : "Presunuté užívateľom {user}",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "You created {file}" : "Vytvorili ste súbor {file}",
    "You created an encrypted file in {file}" : "Vytvorili ste zašifrovaný súbor  {file}",
    "{user} created {file}" : "{user} vytvoril súbor {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvoril šifrovaný súbor {file}",
    "{file} was created in a public folder" : "{file} bol vytvorený vo verejnom priečinku",
    "You changed {file}" : "Zmenili ste {file}",
    "You changed an encrypted file in {file}" : "Zmenili ste šifrovaný súbor {file}",
    "{user} changed {file}" : "{user} zmenil {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmenil šifrovaný súbor {file}",
    "You deleted {file}" : "Zmazali ste {file}",
    "You deleted an encrypted file in {file}" : "Zmazali ste šifrovaný súbor {file}",
    "{user} deleted {file}" : "{user} zmazal {file}",
    "{user} deleted an encrypted file in {file}" : "{user} zmazal šifrovaný súbor {file}",
    "You restored {file}" : "Obnovili ste {file}",
    "{user} restored {file}" : "{user} obnovil {file}",
    "You renamed {oldfile} to {newfile}" : "Premenovali ste {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} premenoval {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Presunuli ste {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} presunul {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Súbor bol pridaný alebo odstránený z vašich <strong>obľúbených</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong> alebo <strong>premenovaný</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nový súbor alebo priečinok bol <strong>vytvorený</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Súbor alebo priečinok bol <strong>odstránený</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Obmedzte upozornenia na vytvorenie a zmeny na vaše <strong>obľúbené súbory</strong> <em>(Len streamy)</em>",
    "A file or folder has been <strong>restored</strong>" : "Súbor alebo priečinok bol <strong>obnovený</strong>",
    "Unlimited" : "Neobmedzené",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "File handling" : "Nastavenie správania sa k súborom",
    "Maximum upload size" : "Maximálna veľkosť odosielaného súboru",
    "max. possible: " : "najväčšie možné:",
    "Save" : "Uložiť",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Použitím PHP-FPM môžu byť zmeny vykonané do 5 minút.",
    "Missing permissions to edit from here." : "Chýbajú orávnenia pre možnosť tu upravovať.",
    "%s of %s used" : "Využité: %s z %s",
    "%s used" : "%s použitých",
    "Settings" : "Nastavenia",
    "Show hidden files" : "Zobraziť skryté súbory",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Použiť túto adresu pre <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">prístup ku svojím súborom cez WebDAV</a>",
    "Cancel upload" : "Zrušiť nahrávanie",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte zo svojimi zariadeniami!",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "No favorites yet" : "Zatiaľ žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "Tags" : "Štítky",
    "Deleted files" : "Zmazané súbory",
    "Shared with others" : "Sprístupnené ostatným",
    "Shared with you" : "Vám sprístupnené",
    "Shared by link" : "Sprístupnené prostredníctvom odkazu",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "Move" : "Presunúť",
    "A new file or folder has been <strong>deleted</strong>" : "Nový súbor alebo priečinok bol <strong>zmazaný</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Nový súbor alebo priečinok bol<strong>obnovený</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Použi túto adresu pre <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">prístup ku svojím súborom cez WebDAV</a>"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-19.0.7.tgz: nextcloud/apps/files/l10n/sk.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
    "Storage invalid" : "Úložisko nie je platné",
    "Unknown error" : "Neznáma chyba",
    "File could not be found" : "Súbor nie je možné nájsť",
    "Move or copy" : "Presunúť alebo kopírovať",
    "Download" : "Stiahnuť",
    "Delete" : "Zmazať",
    "Home" : "Domov",
    "Close" : "Zavrieť",
    "Favorites" : "Obľúbené",
    "Could not create folder \"{dir}\"" : "Nemožno vytvoriť priečinok \"{dir}\"",
    "This will stop your current uploads." : "Toto zastaví práve prebiehajúce nahrávania.",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Processing files …" : "Spracovávam súbory ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cieľový priečinok \"{dir}\" už neexistuje",
    "Not enough free space" : "Nedostatok voľného miesta",
    "An unknown error has occurred" : "Vyskytla sa neznáma chyba",
    "Uploading …" : "Nahrávanie...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nahrávanie tejto položky nie je podporované",
    "Target folder does not exist any more" : "Cieľový priečinok už neexistuje",
    "Operation is blocked by access control" : "Činnosť je blokovaná kontrolou prístupu",
    "Error when assembling chunks, status code {status}" : "Chyba pri zostavovaní kusov, kód chyby {status}",
    "Actions" : "Akcie",
    "Rename" : "Premenovať",
    "Copy" : "Kopírovať",
    "Choose target folder" : "Vyberte cieľový priečinok",
    "Open" : "Otvoriť",
    "Delete file" : "Zmazať súbor",
    "Delete folder" : "Zmazať priečinok",
    "Disconnect storage" : "Odpojiť úložisko",
    "Could not load info for file \"{file}\"" : "Nebolo možné načítať informácie súboru \"{file}\"",
    "Files" : "Súbory",
    "Details" : "Podrobnosti",
    "Select" : "Vybrať",
    "Pending" : "Čaká",
    "Unable to determine date" : "Nemožno určiť dátum",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť \"{file}\", cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť \"{file}\"",
    "copy" : "kópia",
    "Could not copy \"{file}\", target exists" : "Nie je možné kopírovať \"{file}\", cieľ už existuje",
    "Could not copy \"{file}\"" : "Nie je možné skopírovať \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopírované {origin} do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopírované {origin} a {nbfiles} ostatných súborov do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie je možné premenovať \"{fileName}\", cieľ už neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{targetName}\" je už použitý v priečinku \"{dir}\". Zvoľte prosím iný názov.",
    "Could not rename \"{fileName}\"" : "Nie je možné premenovať \"{file}\"",
    "Could not create file \"{file}\"" : "Nie je možné vytvoriť súbor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie je možné vytvoriť súbor \"{file}\" lebo už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Nie je možné vytvoriť priečinok \"{dir}\" lebo už existuje",
    "Could not fetch file details \"{file}\"" : "Podrobnosti o súbore „{file}“ sa nepodarilo načítať",
    "Error deleting file \"{fileName}\"." : "Chyba pri mazaní súboru \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žiadne výsledky vyhľadávania v ostatných priečinkoch pre {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Ak chcete hľadať v iných priečinkoch, zadajte viac ako dva znaky",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov","%n priečinkov"],
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov","%n súborov"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["vrátane %n skytého","vrátane %n skrytých","vrátane %n skrytých","vrátane %n skrytých"],
    "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávam %n súbor","Nahrávam %n súbory","Nahrávam %n súborov","Nahrávam %n súborov"],
    "New" : "Nový",
    "Select file range" : "Vybrať rozsah súborov",
    "{used} of {quota} used" : "použitých {used} z {quota}",
    "{used} used" : "{used} použitých",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" nie je povolený v názve súboru.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie je povolený typ súboru",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať.",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "_matches '{filter}'_::_match '{filter}'_" : ["zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'","zodpovedá '{filter}'"],
    "View in folder" : "Zobraziť v priečinku",
    "Copied!" : "Skopírované!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre používateľov, ktorí majú prístup k tomuto súboru/priečinku)",
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
    "Favorited" : "Pridané k obľúbeným",
    "Favorite" : "Obľúbené",
    "You can only favorite a single file or folder at a time" : "Do obľúbených je možné zaradovať súbory a zložky len jednotlivo",
    "New folder" : "Nový priečinok",
    "Upload file" : "Nahrať súbor",
    "Recent" : "Nedávne",
    "Not favorited" : "Nie je obľúbený",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add to favorites" : "Pridať do obľúbených",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "Added to favorites" : "Pridané do obľúbených",
    "Removed from favorites" : "Odstránené z obľúbených",
    "You added {file} to your favorites" : "Pridali ste {file} do vašich obľúbených",
    "You removed {file} from your favorites" : "Odstránili ste {file} z vašich obľúbených",
    "File changes" : "Zmeny v súboroch",
    "Created by {user}" : "Vytvorené užívateľom {user}",
    "Changed by {user}" : "Zmenené užívateľom {user}",
    "Deleted by {user}" : "Zmazané užívateľom {user}",
    "Restored by {user}" : "Obnovené užívateľom {user}",
    "Renamed by {user}" : "Premenované užívateľom {user}",
    "Moved by {user}" : "Presunuté užívateľom {user}",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "You created {file}" : "Vytvorili ste súbor {file}",
    "You created an encrypted file in {file}" : "Vytvorili ste zašifrovaný súbor  {file}",
    "{user} created {file}" : "{user} vytvoril súbor {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvoril šifrovaný súbor {file}",
    "{file} was created in a public folder" : "{file} bol vytvorený vo verejnom priečinku",
    "You changed {file}" : "Zmenili ste {file}",
    "You changed an encrypted file in {file}" : "Zmenili ste šifrovaný súbor {file}",
    "{user} changed {file}" : "{user} zmenil {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmenil šifrovaný súbor {file}",
    "You deleted {file}" : "Zmazali ste {file}",
    "You deleted an encrypted file in {file}" : "Zmazali ste šifrovaný súbor {file}",
    "{user} deleted {file}" : "{user} zmazal {file}",
    "{user} deleted an encrypted file in {file}" : "{user} zmazal šifrovaný súbor {file}",
    "You restored {file}" : "Obnovili ste {file}",
    "{user} restored {file}" : "{user} obnovil {file}",
    "You renamed {oldfile} to {newfile}" : "Premenovali ste {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} premenoval {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Presunuli ste {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} presunul {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Súbor bol pridaný alebo odstránený z vašich <strong>obľúbených</strong>",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Obľúbený súbor alebo priečinok bol <strong>zmenený</strong>",
    "All files" : "Všetky súbory",
    "Unlimited" : "Neobmedzené",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "Accept" : "Prijať",
    "Reject" : "Odmietnuť",
    "Incoming ownership transfer from {user}" : "Prichádzajúci prevod vlastníctva od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete prijať {path}?\n\nPozn.: Proces pre prijatie môže trvať až hodinu.",
    "Ownership transfer failed" : "Prevod vlastníctva zlyhal",
    "Your ownership transfer of {path} to {user} failed." : "Prevod vlastníctva {path} od vás na {user} zlyhal.",
    "The ownership transfer of {path} from {user} failed." : "Prevod vlastníctva {path} od {user} zlyhal.",
    "Ownership transfer done" : "Prevod vlastníctva dokončený",
    "Your ownership transfer of {path} to {user} has completed." : "Prevod vami vlastnenej položky {path} na {user} bol dokončený.",
    "The ownership transfer of {path} from {user} has completed." : "Prevod vlastníctva položky {path} od {user} bol dokončený.",
    "in %s" : "v %s",
    "File Management" : "Správa súborov",
    "Transfer ownership of a file or folder" : "Prevod vlastníctva súboru alebo priečinka",
    "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Change" : "Zmeniť",
    "New owner" : "Nový vlastník",
    "Search users" : "Hľadať používateľov",
    "Choose a file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Transfer" : "Prevod",
    "Transfer {path} to {userid}" : "Previesť {path} na {userid}",
    "Invalid path selected" : "Bola vybraná neplatná cesta",
    "Ownership transfer request sent" : "Žiadosť o prevod vlastníctva bola odoslaná",
    "Cannot transfer ownership of a file or folder you don't own" : "Nie je možné preniesť vlastníctvo súboru alebo priečinka, ktorý nevlastníte",
    "Tags" : "Štítky",
    "Unable to change the favourite state of the file" : "Nie je možné zmeniť stav „obľúbené“ daného súboru",
    "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
    "%s used" : "%s použitých",
    "%s%% of %s used" : "Využité %s%% z %s",
    "%1$s of %2$s used" : "Využité: %1$s z %2$s",
    "Settings" : "Nastavenia",
    "Show hidden files" : "Zobraziť skryté súbory",
    "WebDAV" : "WebDAV",
    "Use this address to access your Files via WebDAV" : "Táto adresa sa používa na prístup k vašim súborom prostredníctvom WebDAV",
    "Toggle grid view" : "Prepnúť zobrazenie mriežky",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte zo svojimi zariadeniami!",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "No favorites yet" : "Zatiaľ žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "Deleted files" : "Zmazané súbory",
    "Shares" : "Zdieľania",
    "Shared with others" : "Sprístupnené ostatným",
    "Shared with you" : "Vám sprístupnené",
    "Shared by link" : "Sprístupnené prostredníctvom odkazu",
    "Deleted shares" : "Vymazané zdieľania",
    "Pending shares" : "Čakajúce prístupy",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "Unshare" : "Zneprístupniť",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong> alebo <strong>premenovaný</strong>",
    "A new file or folder has been <strong>created</strong>" : "Nový súbor alebo priečinok bol <strong>vytvorený</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Súbor alebo priečinok bol <strong>odstránený</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Obmedzte upozornenia na vytvorenie a zmeny na vaše <strong>obľúbené súbory</strong> <em>(Len streamy)</em>",
    "A file or folder has been <strong>restored</strong>" : "Súbor alebo priečinok bol <strong>obnovený</strong>",
    "Cannot transfter ownership of a file or folder you don't own" : "Nie je možné preniesť vlastníctvo súboru alebo priečinka, ktorý nevlastníte",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Použiť túto adresu pre <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">prístup ku svojím súborom cez WebDAV</a>"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
